@@ -2,13 +2,18 @@ package Number::Phone;
 
 use strict;
 
+use File::ShareDir;
+use File::Spec::Functions qw(catfile);
+use File::Basename qw(dirname);
+use Cwd qw(abs_path);
+
 use Scalar::Util 'blessed';
 
 use Number::Phone::Country qw(noexport);
 use Number::Phone::StubCountry;
 
 # MUST be in format N.NNNN, see https://github.com/DrHyde/perl-modules-Number-Phone/issues/58
-our $VERSION = '3.4006';
+our $VERSION = '3.6006';
 
 my $NOSTUBS = 0;
 sub import {
@@ -19,6 +24,31 @@ sub import {
   }
 }
 
+sub _find_data_file {
+    my $wanted = shift;
+
+    # giant ball of hate because lib::abs doesn't work on Windows
+    my $this_file = __FILE__;
+    my $this_dir  = dirname($this_file);
+    
+    my @candidate_files = (
+         # if this is $devdir/lib ...
+         catfile($this_dir, qw(.. .. lib .. share), $wanted),
+         # if this is $devdir/blib/lib ...
+         catfile($this_dir, qw(.. .. .. blib lib .. .. share), $wanted),
+         # if this has been installed
+         catfile(File::ShareDir::dist_dir('Number-Phone'), $wanted),
+    );
+    my $file = (grep { -e $_ } @candidate_files)[0];
+
+    if(!$file) {
+        die(
+            "Couldn't find a UK data file amongst:\n".
+            join('', map { "  $_\n" } @candidate_files)
+        );
+    }
+    return $file;
+}
 
 my @is_methods = qw(
     is_valid is_allocated is_in_use
@@ -157,7 +187,15 @@ The prefix codes in 3.4003 and earlier were managed by hand and so got out
 of date. After that release they are mostly derived from libphonenumber.
 libphonenumber's data includes carrier selection codes when they are
 mandatory for dialling so those are now included. This sometimes means that
-some random carrier has been arbitrarily priveleged over others.
+some random carrier has been arbitrarily privileged over others.
+
+As of version 3.6000 the C<areaname> method is documented as taking an optional
+language code. As far as I can tell providing this new parameter to the method
+as provided by all the subclasses on the CPAN won't do any harm.
+
+As of version 3.6000 the C<areaname> method pays attention to your locale
+settings and so you might start getting locale-appropriate versions of
+areanames instead of what you used to get.
 
 =head1 COMPATIBILTY WITH libphonenumber
 
@@ -390,6 +428,13 @@ the superclass definition returns undef.  For instance, for a number
 beginning +44 20 it would return
 'London'.  Note that this may return data in non-ASCII character sets.
 
+This may take an optional language code such as 'de' or 'en'. If
+you provide that then you will get back whatever the place name is
+in that language, if the data is available. If you don't provide
+it then it will first look at your locale settings and try to find
+a name in an appropriate language, and if nothing is found fall
+back to English.
+
 =item location
 
 This returns an approximate geographic location for the number if possible.
@@ -605,6 +650,10 @@ The constructor returns undef if it can not figure out what country
 you're talking about, or an object based on Google's libphonenumber
 data if there's no complete country-specific module available.
 
+It is generally assumed that numbers are complete and unambiguous - ie you
+can't pass just the local part to the constructor if the number has an area
+code. Any subclass's constructor which contravenes this should document it.
+
 =back
 
 =head1 SUBCLASSING
@@ -629,8 +678,17 @@ going like Number::Phone::NANP::XX.
 
 =head1 UPDATES
 
-Starting in March 2015 I intend to release updates approximately every
-three months, including new data from libphonenumber and OFCOM.
+I release updates approximately every three months, including new data.
+
+I will also do intercalary releases to fix *serious* bugs in the code
+and when *large* data updates (eg when a country's numbering scheme changes)
+are brought to my attention.
+
+I will not normally do a release just because a country has added some
+new number range. If this irks you then I would welcome a discussion on
+how you can best write a patch, with tests, that will reliably incorporate
+updated data from libphonenumber. Much of the needed code already exists
+in the repository but it is not fit for end-user consumption.
 
 =head1 BUGS/FEEDBACK
 
