@@ -5,7 +5,7 @@ use Number::Phone::Country::Data;
 
 # *_codes are global so we can mock in some tests
 use vars qw($VERSION %idd_codes %prefix_codes);
-$VERSION = 1.94;
+$VERSION = 1.96;
 my $use_uk = 0;
 
 sub import {
@@ -32,12 +32,12 @@ sub phone2country {
 our %NANP_areas = (
     CA => do {
         # see http://www.cnac.ca/co_codes/co_code_status.htm
-        # checked on 2018-12-04
-        # next check due 2019-06-01 (semi-annually)
+        # checked on 2020-06-06
+        # next check due 2020-12-01 (semi-annually)
         my $canada = join('|', qw(
             204 226 236 249 250 289
-            306 343 365 367
-            403 416 418 428 431 437 438 450
+            306 343 354 365 367 368
+            403 416 418 428 431 437 438 450 474
             506 514 519 548 579 581 587
             604 613 639 647 672
             705 709 778 780 782
@@ -46,37 +46,39 @@ our %NANP_areas = (
         ));
         # handful of non-geographic country-specific codes ...
         # see https://en.wikipedia.org/wiki/Area_code_600
-        # checked on 2018-12-04
-        # next check due 2019-06-01 (semi-annually)
+        # checked on 2020-06-06
+        # next check due 2020-12-01 (semi-annually)
         $canada = join('|', $canada, 600, 622, 633, 644, 655, 677, 688);
     },
     US => do {
         # see https://www.allareacodes.com/area_code_listings_by_state.htm
-        #   (should I treat this as authoritative?)
-        #   maybe use https://en.wikipedia.org/wiki/List_of_North_American_Numbering_Plan_area_codes#United_States instead
-        # checked on 2018-12-04
-        # next check due 2019-06-01 (semi-annually)
+        # and https://en.wikipedia.org/wiki/List_of_North_American_Numbering_Plan_area_codes#United_States
+        # NB for Hyder, Alaska, it shares three COs with Stewart, BC, and we can't tell which number is in which country,
+        #   so those prefixes aren't listed here
+        # checked on 2020-06-06
+        # next check due 2020-12-01 (semi-annually)
         my $usa = join('|', qw(
-            205 251 256 334 938
+            205 251 256 334 659 938
             907
             480 520 602 623 928
-            479 501 870
-            209 213 310 323 408 415 424 442 510 530 559 562 619 626 628 650 657 661 669 707 714 747 760 805 818 831 858 909 916 925 949 951
+            327 479 501 870
+            209 213 279 310 323 341 408 415 424 442 510 530 559 562 619 626 628 650 657 661 669 707 714 747 760 805 818 820 831 840 858 909 916 925 949 951
             303 719 720 970
             203 475 860 959
             302
-            239 305 321 352 386 407 561 727 754 772 786 813 850 863 904 941 954
+            202
+            239 305 321 352 386 407 448 561 656 689 727 754 772 786 813 850 863 904 941 954
             229 404 470 478 678 706 762 770 912
             808
-            208
-            217 224 309 312 331 618 630 708 773 779 815 847 872
+            208 986
+            217 224 309 312 331 447 464 618 630 708 730 773 779 815 847 872
             219 260 317 463 574 765 812 930
             319 515 563 641 712
             316 620 785 913
             270 364 502 606 859
             225 318 337 504 985
             207
-            240 301 410 443 667
+            227 240 301 410 443 667
             339 351 413 508 617 774 781 857 978
             231 248 269 313 517 586 616 734 810 906 947 989
             218 320 507 612 651 763 952
@@ -86,38 +88,37 @@ our %NANP_areas = (
             308 402 531
             702 725 775
             603
-            201 551 609 732 848 856 862 908 973
+            201 551 609 640 732 848 856 862 908 973
             505 575
-            212 315 332 347 516 518 585 607 631 646 680 716 718 845 914 917 929 934
+            212 315 332 347 516 518 585 607 631 646 680 716 718 838 845 914 917 929 934
             252 336 704 743 828 910 919 980 984
             701
-            216 220 234 330 380 419 440 513 567 614 740 937
-            405 539 580 918
+            216 220 234 326 330 380 419 440 513 567 614 740 937
+            405 539 572 580 918
             458 503 541 971
-            215 267 272 412 484 570 610 717 724 814 878
+            215 223 267 272 412 445 484 570 610 717 724 814 878
             401
-            803 843 854 864
+            803 839 843 854 864
             605
             423 615 629 731 865 901 931
-            210 214 254 281 325 346 361 409 430 432 469 512 682 713 737 806 817 830 832 903 915 936 940 956 972 979
+            210 214 254 281 325 346 361 409 430 432 469 512 682 713 726 737 806 817 830 832 903 915 936 940 956 972 979
             385 435 801
             802
-            276 434 540 571 703 757 804
-            206 253 360 425 509
-            202
+            276 434 540 571 703 757 804 948
+            206 253 360 425 509 564
             304 681
-            262 414 534 608 715 920
+            262 274 414 534 608 715 920
             307
         ));
         # handful of non-geographic country-specific codes ...
         # see https://en.wikipedia.org/wiki/Area_code_710
-        # checked on 2018-12-04
-        # next check due 2019-06-01 (semi-annually)
+        # checked on 2019-12-11
+        # next check due 2021-12-01 (bi-annually)
         $usa    = join('|', $usa, 710);
     },
-    # see https://en.wikipedia.org/wiki/North_American_Numbering_Plan#NANP_countries_and_territories
-    # checked on 2018-12-04
-    # next check due 2019-06-01 (semi-annually)
+    # see https://en.wikipedia.org/wiki/North_American_Numbering_Plan#Countries_and_territories
+    # checked on 2020-06-06
+    # next check due 2020-12-01 (semi-annually)
     AS => '684',         # American Samoa
     AI => '264',         # Anguilla
     AG => '268',         # Antigua and Barbude
@@ -150,6 +151,15 @@ sub _NANP_area_codes {
     return split('\|', $NANP_areas{shift()});
 }
 
+# private sub, returns list of NANP areas that *aren't* in the US or Canada
+sub _non_US_CA_area_codes {
+    # uncoverable subroutine - only used in build scripts
+    return sort split('\|', join('|',
+        @NANP_areas{grep { $_ !~ /^(US|CA)$/ } keys %NANP_areas}
+    ));
+
+}
+
 sub phone2country_and_idd {
     my ($phone) = @_;
     $phone =~ s/[^\+?\d+]//g;
